;;; --------------------------------------------------------------------------
;;; File     : DDChAcad.lsp
;;; Copyright: cad nauseam, 1996-2001.
;;; Purpose  : To provide auto-loading of DDCHTEXT and DC commands,
;;;            (naus_ddchtext_*) functions, and toolbar menu if appropriate.
;;;            Load this file at startup time, e.g. from ACAD.LSP or
;;;            ACADDOC.LSP.
;;; Note     : To prevent the toolbar menu loading, search for ** in this file.
;;; Version  : 3.1
;;; Date     : 19 September 2001
;;; --------------------------------------------------------------------------

(princ "\nDDChText 3.1 ")

(if (not C:DDCHTEXT)
  (progn  ; Only define all these functions if it's not already done


;; ---------------------------------------------------------------------------
;; Function : C:DDCHTEXT
;; Purpose  : Auto-loading stub for (C:DDCHTEXT)
;; ---------------------------------------------------------------------------

    (defun C:DDCHTEXT ()
      (naus_ddchload)
      (C:DDCHTEXT)
    ) ; End C:DDCHTEXT (stub)

;; ---------------------------------------------------------------------------
;; Function : C:DC
;; Purpose  : Short-form version of DDCHTEXT command
;; ---------------------------------------------------------------------------

    (defun C:DC () (C:DDCHTEXT)) ; End C:DC

;; ---------------------------------------------------------------------------
;; Function : naus_ddchpath
;; Purpose  : Returns a file path which allows for the use of one of the
;;            NAUS-DDCHDPREFIX or NAUS-ALLPREFIX global variables, or the
;;            DDCHTEXT or CAD-NAUSEAM OS variables.
;; ---------------------------------------------------------------------------

    (defun naus_ddchpath (FNAME / prefix)
      (strcat
        (cond
          (NAUS-DDCHPREFIX NAUS-DDCHPREFIX)
          (NAUS-ALLPREFIX NAUS-ALLPREFIX)
          ((setq prefix (getenv "DDCHTEXT")) prefix)
          ((setq prefix (getenv "CAD-NAUSEAM")) prefix)
          (T "")
        )
        FNAME
      )
    ) ; End naus_ddchpath

;; ---------------------------------------------------------------------------
;; Function : naus_ddchload
;; Purpose  : Loads either the registered version of DDCHTEXT or, if not
;;            available, the unregistered version.
;; ---------------------------------------------------------------------------

    (defun naus_ddchload ()
      (if (= 'failed (load (naus_ddchpath "DDCHREG") 'failed))
        (if (= 'failed (load (naus_ddchpath "DDCHTEXT") 'failed))
          (alert "Cannot load AutoLISP file for DDCHTEXT")
        )
      )
    ) ; End naus_ddchload

;; ---------------------------------------------------------------------------
;; Function : naus_ddchloadmenu
;; Purpose  : Loads the DDCHTEXT toolbar menu
;; ---------------------------------------------------------------------------

    (defun naus_ddchloadmenu (/ loadmenu)
      (naus_load_toolbar_menu
        (naus_ddchpath
          (strcat
            "DDCH"
            (cond
              ((wcmatch (getvar "ACADVER") "*13*") "TE13")
              ((getvar "DIMASSOC") "2002")
              (T "TEXT")
            )
          )
        )
        "DDCHTEXT"
        "ID_DDChPop01"
      )
      (princ)
    ) ; End naus_ddchloadmenu

;; ---------------------------------------------------------------------------
;; Function : naus_load_toolbar_menu
;; Purpose  : Loads a toolbar menu
;; ---------------------------------------------------------------------------

    (defun naus_load_toolbar_menu (FNAME MGROUP ID / cmdecho)
      (if
        (and
          (wcmatch (getvar "PLATFORM") "*Windows*")
          (wcmatch (getvar "ACADVER") "*13*,*14*,*15*,*16*")
        )
        (progn
          (if (wcmatch (getvar "ACADVER") "*13*")
            (while (not (menucmd "P1.1=?"))) ; Wait for menu before acting
          )
          (if (not (menucmd (strcat "G" MGROUP "." ID "=?")))
            (progn
              (setq cmdecho (getvar "CMDECHO"))
              (setvar "CMDECHO" 0)
              (command)
              (command "_.MENULOAD" FNAME)
              (setvar "CMDECHO" cmdecho)
            )
          )
        ) ; End progn
        (princ (strcat "\nWARNING: Can't load toolbar menu " FNAME ". "))
      )
      (princ)
    ) ; End naus_load_toolbar_menu

;; ---------------------------------------------------------------------------
;; Function : naus_startup_add
;; Purpose  : Adds some code to the S::STARTUP function
;; ---------------------------------------------------------------------------

    (defun naus_startup_add (CODE / # funcname)
      (cond                             ; What is S::STARTUP?
        ((not S::STARTUP)               ; It's not defined yet
         (setq S::STARTUP (list nil CODE)) ; So make it the code passed in
        )
        ((listp S::STARTUP)             ; It's a list-based function
         (if (not (member CODE S::STARTUP)) ; Make sure we don't re-add code
           (setq S::STARTUP (append S::STARTUP (list CODE))) ; Add code
         )
        )
        (T                              ; It must be a subr or exsubr or usubr
         (setq # 0)
         (while                         ; Find unused NAUS_OLD_STARTUP_n symbol
           (eval
             (setq
               funcname
                (read (strcat "NAUS_OLD_STARTUP_" (itoa (setq # (1+ #)))))
             )
           )
         )
         (set funcname S::STARTUP)      ; (setq OLD_STARTUP_n S::STARTUP)
         (setq S::STARTUP (list nil (list funcname) CODE)) ; Make S::STARTUP
        )
      )
    ) ; End naus_startup_add

;; ---------------------------------------------------------------------------
;; Function : naus_ddchtext_en
;; Purpose  : Auto-loading stub for (naus_ddchtext_en)
;; ---------------------------------------------------------------------------

    (defun naus_ddchtext_en (EN / prefix)
      (naus_ddchload)
      (naus_ddchtext_en EN)
    ) ; End naus_ddchtext_en (stub)

;; ---------------------------------------------------------------------------
;; Function : naus_ddchtext_dialog
;; Purpose  : Auto-loading stub for (naus_ddchtext_dialog)
;; ---------------------------------------------------------------------------

    (defun naus_ddchtext_dialog (INIT / prefix)
      (naus_ddchload)
      (naus_ddchtext_dialog INIT)
    ) ; End naus_ddchtext_dialog (stub)

;; ---------------------------------------------------------------------------
;; Function : naus_ddchtext_modss
;; Purpose  : Auto-loading stub for (naus_ddchtext_modss)
;; ---------------------------------------------------------------------------

    (defun naus_ddchtext_modss (SS MOD-LIST TAG VOCAL UPDATE / prefix)
      (naus_ddchload)
      (naus_ddchtext_modss SS MOD-LIST TAG VOCAL UPDATE)
    ) ; End naus_ddchtext_modss (stub)

;; ---------------------------------------------------------------------------
;; Function : naus_ddchtext_modentity
;; Purpose  : Auto-loading stub for (naus_ddchtext_modentity)
;; ---------------------------------------------------------------------------

    (defun naus_ddchtext_modentity (EG MOD-LIST UPDATE / prefix)
      (naus_ddchload)
      (naus_ddchtext_modentity EG MOD-LIST UPDATE)
    ) ; End naus_ddchtext_modentity (stub)


;; ---------------------------------------------------------------------------
;; We've finished defining functions, so now we can actually do stuff.
;; ---------------------------------------------------------------------------

;; ** User-modifiable code
;;    If you do not wish to load the toolbar menu, place a single semi-colon
;;    (;) at the start of the next line
    (naus_startup_add '(naus_ddchloadmenu)) ; Add menu load call to S::STARTUP

    (if vl-doc-import ; Export global variables (only relevant in vlisp)
      (foreach one
       '(naus_ddchload         naus_ddchpath
         naus_ddchtext_en      naus_ddchtext_dialog
         naus_ddchtext_modss   naus_ddchtext_modentity)
        (vl-doc-import one)
      )
    )
    (princ "autoloaded. ")

  ) ; End progn
  (princ "already loaded. ") ; Display if 2nd attempt at loading is made.
) ; End if (not C:DDCHTEXT)

(princ)

;;; --------------------------------------------------------------------------
;;; End DDChAcad.lsp
;;; --------------------------------------------------------------------------