//// -------------------------------------------------------------------------
//// File     : DDChText.dcl
//// Copyright: cad nauseam, 1996-2001.  Shareware, NOT freeware.
////            All rights reserved.
//// Author   : Steve Johnson
//// Purpose  : Dialogue box definition for DDChText command.
//// Version  : 3.1
//// Date     : 19 September 2001
//// -------------------------------------------------------------------------


/// --------------------------------------------------------------------------
/// Turn off error checking
/// --------------------------------------------------------------------------

dcl_settings : default_dcl_settings { audit_level = 0; }


/// --------------------------------------------------------------------------
/// Widget : ddchtext
/// Purpose: Main DDCHTEXT dialogue box.
/// --------------------------------------------------------------------------

ddchtext : dialog {
  label                 = "DDChText";
  key                   = "title";
  : row {
    : column {
      all_toggle;
      properties_set;
    }
    values_set;
  }
  : row {
    settings_set;
    : column {
      attrib_set;
      : row {
        object_set;
        finish_buttons;
      }
    }
  }
  errtile;
} // End ddchtext


/// --------------------------------------------------------------------------
/// Widget : list_layers
/// Purpose: Sub dialogue box used to list the current drawing's layers and
///          allow the user to select one.
/// --------------------------------------------------------------------------

list_layers : dialog {
  label                 = "Layers";
  ddch_list;
  spacer;
  ok_cancel_err;
} // End list_layers


/// --------------------------------------------------------------------------
/// Widget : list_blocks
/// Purpose: This is a sub dialogue box used to list the currently defined
///          blocks and allow the user to select one.
/// --------------------------------------------------------------------------

list_blocks : dialog {
  label                 = "Blocks";
  : ddch_list {
    multiple_select     = true;
  }
  spacer;
  ok_cancel_err;
} // End list_blocks


/// --------------------------------------------------------------------------
/// Widget : list_tags
/// Purpose: This is a sub dialogue box used to list the tags of attributes
///          in the currently defined blocks and allow the user to select one.
/// --------------------------------------------------------------------------

list_tags : dialog {
  label                 = "Tags";
  : ddch_list {
    multiple_select     = true;
  }
  spacer;
  ok_cancel_err;
} // End list_tags


/// --------------------------------------------------------------------------
/// Widget : multiple_replace
/// Purpose: This is a sub dialogue box used to list the tags of attributes
///          in the currently defined blocks and allow the user to select one.
/// --------------------------------------------------------------------------

multiple_replace : dialog {
  label                 = "Multiple Search and Replace";
  : toggle {
    key                 = "multiple_use";
    label               = "Use Multiple Search and Replace";
  }
  : column {
    key                 = "multiple_main";
    is_enabled          = false;
    : boxed_column {
      : row {
        : text {
          width         = 10;
          label         = "Search";
        }
        : edit_box {
          key           = "multiple_search";
          width         = 70;
        }
      }
      : row {
        : text {
          width         = 10;
          label         = "Replace";
        }
        : edit_box {
          key           = "multiple_replace";
          width         = 70;
        }
      }
      : toggle {
        label           = "Case sensitive search";
        key             = "multiple_case";
      }
      : row {
        : ddch_button {
          label         = "Insert";
          key           = "multiple_insert";
        }
        : ddch_button {
          label         = "Append";
          key           = "multiple_add";
        }
        : ddch_button {
          label         = "Replace";
          key           = "multiple_overwrite";
        }
        : ddch_button {
          label         = "Delete";
          key           = "multiple_delete";
        }
        : ddch_button {
          label         = "Delete All";
          key           = "multiple_clear";
        }
      }
    }
    : list_box {
      width             = 80;
      height            = 12;
      key               = "list_box";
      tabs              = "38 76";
    }
    spacer;
    : boxed_row {
      label             = "Files";
      : ddch_mid_button {
        label           = "Save...";
        key             = "multiple_save";
      }
      : ddch_mid_button {
        label           = "Load...";
        key             = "multiple_load";
      }
      : ddch_mid_button {
        label           = "Merge...";
        key             = "multiple_merge";
      }
    }
  }
  spacer;
  ok_cancel_err;
} // End multiple_replace


/// --------------------------------------------------------------------------
/// Widget : all_toggle
/// Purpose: Row of toggles for turning on/off all modification or object type
///          toggles.
/// --------------------------------------------------------------------------

all_toggle : boxed_row {
 label                  = "Toggle all";
  : toggle {
    key                 = "all_toggle";
    label               = "Modifications";
  }
  spacer;
  : toggle {
    key                 = "all_object";
    label               = "Object types";
  }
} // End all_toggle


/// --------------------------------------------------------------------------
/// Widget : properties_set
/// Purpose: Column containing widgets for layer and color settings.
/// --------------------------------------------------------------------------

properties_set : boxed_column {
  label                 = "Properties";
  layer_set;
  color_set;
} // End properties_set


/// --------------------------------------------------------------------------
/// Widget : values_set
/// Purpose: Toggle-controlled row with edit boxes for search and replace text
///          and toggle for case-sensitivity.
/// --------------------------------------------------------------------------

values_set : boxed_column {
  label                 = "Values";
  search_set;
  case_set;
  mtextcode_set;
} // End values_set


/// --------------------------------------------------------------------------
/// Widget : settings_set
/// Purpose: Column containing widgets for most text settings.
/// --------------------------------------------------------------------------

settings_set : boxed_column {
  label                 = "Settings";
  height_set;
  width_set;
  mtextwidth_set;
  rotation_set;
  oblique_set;
  style_set;
  justify_set;
  visible_set;
} // End settings_set


/// --------------------------------------------------------------------------
/// Widget : attrib_set
/// Purpose: Boxed column with edit boxes for block and tag names/wildcards.
/// --------------------------------------------------------------------------

attrib_set : boxed_column {
  key                   = "attrib_area";
  label                 = "Attribute filters";
  : row {
    : ddch_mid_button {
      label             = "Block name...";
      key               = "block_button";
    }
    : ddch_mid_edit {
      key               = "block";
      label             = "";
    }
  }
  : row {
    : ddch_mid_button {
      label             = "Tag name...";
      key               = "tag_button";
    }
    : ddch_mid_edit {
      key               = "tag";
      label             = "";
    }
  }
} // End attrib_set


/// --------------------------------------------------------------------------
/// Widget : object_set
/// Purpose: Radio column to allow user to choose object type to change.
/// --------------------------------------------------------------------------

object_set : boxed_column {
  label                 = "Object types";
  key                   = "object";
  : toggle {
    key                 = "attdef";
    label               = "Attdef";
  }
  : toggle {
    key                 = "attrib";
    label               = "Attribute";
  }
  : toggle {
    key                 = "dimension";
    label               = "Dimension";
  }
  : toggle {
    key                 = "mtext";
    label               = "Mtext";
  }
  : toggle {
    key                 = "rtext";
    label               = "Rtext";
  }
  : toggle {
    key                 = "text";
    label               = "Text";
  }
} // End object_set


/// --------------------------------------------------------------------------
/// Widget : finish_buttons
/// Purpose: Row of buttons at bottom of dialogue.
/// --------------------------------------------------------------------------

finish_buttons : column {
  : spacer { height     = 6; }
  select_button;
  all_button;
  wide_cancel_button;
} // End finish_buttons


/// --------------------------------------------------------------------------
/// Widget : layer_set
/// Purpose: Toggle-controlled row with button and edit box for text layer.
/// --------------------------------------------------------------------------

layer_set : ddch_set {
  children_fixed_width  = true;
  : toggle {
    key                 = "layer_toggle";
    label               = "Layer";
    width               = 10;
  }
  : row {
    key                 = "layer_area";
    : ddch_button {
      label             = "Layer...";
      key               = "layer_button";
    }
    : ddch_mid_edit {
      key               = "layer";
    }
  }
} // End layer_set


/// --------------------------------------------------------------------------
/// Widget : color_set
/// Purpose: Toggle-controlled row with button and edit box for text colour.
/// --------------------------------------------------------------------------

color_set : ddch_set {
  children_fixed_width  = true;
  : toggle {
    key                 = "color_toggle";
    label               = "Color";
    width               = 10;
  }
  : row {
    key                 = "color_area";
    : ddch_button {
      label             = "Color...";
      key               = "color_button";
    }
    : ddch_mid_edit {
      key               = "color";
    }
  }
} // End color_set


/// --------------------------------------------------------------------------
/// Widget : search_set
/// Purpose: Toggle-controlled row with search and replace edit boxes, toggle
///          for case sensitivity, and button to provide access to multiple
///          search and replace sub-dialogue.
/// --------------------------------------------------------------------------

search_set : ddch_set {
  children_fixed_width  = true;
  : toggle {
    key                 = "search_toggle";
    label               = "Replace";
    width               = 10;
  }
  : row {
    key                 = "search_area";
    : column {
      : text {
        label           = "Search";
      }
      : text {
        label           = "Replace";
      }
    }
    : column {
      : row {
        : ddch_mid_edit {
          label         = "";
          key           = "search";
        }
      }
      : row {
        : ddch_mid_edit {
          label         = "";
          key           = "replace";
        }
      }
    }
    : column {
      : toggle {
        label           = "Case sen.";
        key             = "case";
        is_enabled      = false;
      }
      : ddch_button {
        label           = "Multiple...";
        key             = "multiple_button";
      }
    }
  }
} // End search_set


/// --------------------------------------------------------------------------
/// Widget : case_set
/// Purpose: Toggle-controlled row with radio buttons to choose which case to
///          set the text to.
/// --------------------------------------------------------------------------

case_set : ddch_set {
  children_fixed_width  = true;
  : toggle {
    key                 = "upcase_toggle";
    label               = "Set case";
    width               = 10;
  }
  : radio_row {
    key                 = "upcase_area";
    : radio_button {
      key               = "upper";
      label             = "Upper";
    }
    : radio_button {
      key               = "mixed";
      label             = "Title";
    }
    : radio_button {
      key               = "sentence";
      label             = "Sentence";
    }
    : radio_button {
      key               = "lower";
      label             = "Lower";
    }
  }
} // End case_set


/// --------------------------------------------------------------------------
/// Widget : mtextcode_set
/// Purpose: Toggle-controlled row with radio buttons for different operations
///          to be performed on mtext codes.
/// --------------------------------------------------------------------------

mtextcode_set : ddch_set {
  : toggle {
    key                 = "mtextcode_toggle";
    label               = "Mtext codes";
    width               = 10;
  }
  : radio_row {
    key                 = "mtextcode_area";
    : radio_button {
      key               = "mtextcode_strip_height";
      label             = "Relative height";
    }
    : radio_button {
      key               = "mtextcode_strip_all";
      label             = "Strip all";
    }
  }
} // End mtextcode_set


/// --------------------------------------------------------------------------
/// Widget : height_set
/// Purpose: Toggle-controlled row with edit box for text height.
/// --------------------------------------------------------------------------

height_set : ddch_set {
  : ddch_toggle {
    key                 = "height_toggle";
    label               = "Height";
  }
  : row {
    key                 = "height_area";
    : ddch_edit {
      key               = "height";
    }
  }
  : toggle {
    key                 = "height_relative";
    label               = "x Current";
    is_enabled          = false;
  }
} // End height_set


/// --------------------------------------------------------------------------
/// Widget : width_set
/// Purpose: Toggle-controlled row with edit box for text width.
/// --------------------------------------------------------------------------

width_set : ddch_set {
  : ddch_toggle {
    key                 = "width_toggle";
    label               = "Width factor";
  }
  : row {
    key                 = "width_area";
    : ddch_edit {
      key               = "width";
    }
  }
  : toggle {
    key                 = "width_relative";
    label               = "x Current";
    is_enabled          = false;
  }
} // End width_set


/// --------------------------------------------------------------------------
/// Widget : mtextwidth_set
/// Purpose: Toggle-controlled row with edit box for mtext width.
/// --------------------------------------------------------------------------

mtextwidth_set : ddch_set {
  : ddch_toggle {
    key                 = "mtextwidth_toggle";
    label               = "Mtext width";
  }
  : row {
    key                 = "mtextwidth_area";
    : ddch_edit {
      key               = "mtextwidth";
    }
  }
  : toggle {
    key                 = "mtextwidth_relative";
    label               = "x Current";
    is_enabled          = false;
  }
} // End mtextwidth_set


/// --------------------------------------------------------------------------
/// Widget : rotation_set
/// Purpose: Toggle-controlled row with edit box for text rotation angle.
/// --------------------------------------------------------------------------

rotation_set : ddch_set {
  : ddch_toggle {
    key                 = "rotation_toggle";
    label               = "Rotation angle";
  }
  : row {
    key                 = "rotation_area";
    : ddch_edit {
      key               = "rotation";
    }
  }
  : toggle {
    key                 = "rotation_relative";
    label               = "+ Current";
    is_enabled          = false;
  }
} // End rotation_set


/// --------------------------------------------------------------------------
/// Widget : oblique_set
/// Purpose: Toggle-controlled row with edit box for text oblique angle.
/// --------------------------------------------------------------------------

oblique_set : ddch_set {
  : ddch_toggle {
    key                 = "oblique_toggle";
    label               = "Obliquing angle";
  }
  : row {
    key                 = "oblique_area";
    : ddch_edit {
      key               = "oblique";
    }
  }
  : toggle {
    key                 = "oblique_relative";
    label               = "+ Current";
    is_enabled          = false;
  }
} // End oblique_set


/// --------------------------------------------------------------------------
/// Widget : style_set
/// Purpose: Toggle-controlled row with popup list box for text style.
/// --------------------------------------------------------------------------

style_set : ddch_set {
  : ddch_toggle {
    key                 = "style_toggle";
    label               = "Style";
  }
  : row {
    key                 = "style_area";
    : ddch_wide_popup {
      key               = "style";
    }
  }
} // End style_set


/// --------------------------------------------------------------------------
/// Widget : justify_set
/// Purpose: Toggle-controlled row with popup list box for text justification.
/// --------------------------------------------------------------------------

justify_set : ddch_set {
  : ddch_toggle {
    key                 = "justify_toggle";
    label               = "Justification";
  }
  : row {
    key                 = "justify_area";
    : ddch_popup {
      key               = "justify";
    }
    : toggle {
      key               = "justify_relative";
      label             = "In situ";
    }
  }
} // End justify_set


/// --------------------------------------------------------------------------
/// Widget : visible_set
/// Purpose: Toggle-controlled row with edit box for text obliqueing angle.
/// --------------------------------------------------------------------------

visible_set : ddch_set {
  : ddch_toggle {
    key                 = "visible_toggle";
    label               = "Attribute visibility";
  }
  : row {
    key                 = "visible_area";
    : toggle {
      key               = "visible_relative";
      label             = "Visible";
      is_enabled        = false;
    }
  }
} // End visible_set


/// --------------------------------------------------------------------------
/// Widget : wide_cancel_button
/// Purpose: Cancel button that fills the available width.
/// --------------------------------------------------------------------------

wide_cancel_button : ddch_retirement_button {
  label                 = "Cancel";
  key                   = "cancel";
  is_cancel             = true;
} // End wide_cancel_button


/// --------------------------------------------------------------------------
/// Widget : select_button
/// Purpose: Retirement button marked "OK" (previously "Select").
/// --------------------------------------------------------------------------

select_button : ddch_retirement_button {
  label                 = "OK";
  key                   = "select_ok";
  is_default            = true;
} // End select_button


/// --------------------------------------------------------------------------
/// Widget : all_button
/// Purpose: Retirement button marked "Global" (previously marked "All").
/// --------------------------------------------------------------------------

all_button : ddch_retirement_button {
  label                 = "Global";
  key                   = "all_ok";
} // End all_button


/// --------------------------------------------------------------------------
/// Widget : ddch_retirement_button
/// Purpose: Standard width retirement button for main dialogue box.
/// --------------------------------------------------------------------------

ddch_retirement_button : retirement_button {
  width                 = 18;
} // End ddch_retirement_button


/// --------------------------------------------------------------------------
/// Widget : ddch_set
/// Purpose: General row definition for toggle-controlled rows.
/// --------------------------------------------------------------------------

ddch_set : row {
  fixed_width           = true;
  is_enabled            = false;
} // End ddch_set


/// --------------------------------------------------------------------------
/// Widget : ddch_toggle
/// Purpose: General toggle definition for toggle-controlled rows.
/// --------------------------------------------------------------------------

ddch_toggle : toggle {
  width                 = 22;
} // End ddch_toggle


/// --------------------------------------------------------------------------
/// Widget : ddch_edit
/// Purpose: General small edit box definition.
/// --------------------------------------------------------------------------

ddch_edit : edit_box {
  edit_width            = 15;
  is_enabled            = false;
} // End ddch_edit


/// --------------------------------------------------------------------------
/// Widget : ddch_mid_edit
/// Purpose: General medium size edit box definition.
/// --------------------------------------------------------------------------

ddch_mid_edit : edit_box {
  edit_width            = 15;
  is_enabled            = false;
} // End ddch_mid_edit


/// --------------------------------------------------------------------------
/// Widget : ddch_button
/// Purpose: General button definition.
/// --------------------------------------------------------------------------

ddch_button : button {
  width                 = 12;
  fixed_width           = true;
  is_enabled            = false;
} // End ddch_button


/// --------------------------------------------------------------------------
/// Widget : ddch_mid_button
/// Purpose: General mid-sized button definition.
/// --------------------------------------------------------------------------

ddch_mid_button : button {
  width                 = 20;
  fixed_width           = true;
} // End ddch_mid_button


/// --------------------------------------------------------------------------
/// Widget : ddch_wide_popup
/// Purpose: General wide popup list definition.
/// --------------------------------------------------------------------------

ddch_wide_popup : popup_list {
  edit_width            = 31;
  fixed_width           = true;
  is_enabled            = false;
} // End ddch_wide_popup


/// --------------------------------------------------------------------------
/// Widget : ddch_popup
/// Purpose: General popup list definition.
/// --------------------------------------------------------------------------

ddch_popup : popup_list {
  edit_width            = 18;
  fixed_width           = true;
  is_enabled            = false;
} // End ddch_popup


/// --------------------------------------------------------------------------
/// Widget : ddch_list
/// Purpose: General list box definition.
/// --------------------------------------------------------------------------

ddch_list : list_box {
  key                   = "list_box";
  width                 = 31;
  height                = 20;
} // End ddch_list


/// --------------------------------------------------------------------------
/// End DDChText.dcl
/// --------------------------------------------------------------------------